API docs for “spamfighter.utils”

# Package s.utils

Part of spamfighter View Source

Различные утилиты и вспомогательные классы.

Module | config | Питоновский враппер конфигурационных XML файлов
Module | registrator | Декоратор регистрации, позволяющий получить текущий класс в функции,
Module | terminal | Terminal controller module.
Package | test | Тесты на `spamfighter.utils`.
Module | time | Модуль подсчета "неточного" времени (разрешение одна секунда). Доступен